summaryrefslogtreecommitdiff
path: root/buildscripts/packager.py
diff options
context:
space:
mode:
authorGabriel Russell <gabriel.russell@mongodb.com>2016-09-27 13:23:09 -0400
committerGabriel Russell <gabriel.russell@mongodb.com>2016-10-03 13:16:22 -0400
commit6970945d92b0938dee3ae77d2aff8d0a95cbfc4a (patch)
tree625d6d554c5d2dbfef2f9e410751338d6a7d3b11 /buildscripts/packager.py
parentfd300c0c05c1e057a7c5f24e7599d26e383234d0 (diff)
downloadmongo-6970945d92b0938dee3ae77d2aff8d0a95cbfc4a.tar.gz
SERVER-26376 add mongoreplay to release
Diffstat (limited to 'buildscripts/packager.py')
-rwxr-xr-xbuildscripts/packager.py9
1 files changed, 4 insertions, 5 deletions
diff --git a/buildscripts/packager.py b/buildscripts/packager.py
index 1d46aa6419e..97c3a95f275 100755
--- a/buildscripts/packager.py
+++ b/buildscripts/packager.py
@@ -447,11 +447,10 @@ def make_package(distro, build_os, arch, spec, srcdir):
# packaging infrastructure will move the files to wherever they
# need to go.
unpack_binaries_into(build_os, arch, spec, sdir)
- # Remove the mongosniff binary due to libpcap dynamic
- # linkage. FIXME: this removal should go away
- # eventually.
- if os.path.exists(sdir + "bin/mongosniff"):
- os.unlink(sdir + "bin/mongosniff")
+ # Remove the mongoreplay binary due to libpcap dynamic
+ # linkage.
+ if os.path.exists(sdir + "bin/mongoreplay"):
+ os.unlink(sdir + "bin/mongoreplay")
return distro.make_pkg(build_os, arch, spec, srcdir)
def make_repo(repodir, distro, build_os, spec):